package com.xinda.iot.service;

import java.util.List;
import com.xinda.iot.domain.DeviceModel;

/**
 * 产品型号Service接口
 * 
 * @author kerwincui
 * @date 2025-01-20
 */
public interface IDeviceModelService 
{
    /**
     * 查询产品型号
     * 
     * @param id 产品型号主键
     * @return 产品型号
     */
    public DeviceModel selectDeviceModelById(Long id);

    /**
     * 查询产品型号列表
     * 
     * @param deviceModel 产品型号
     * @return 产品型号集合
     */
    public List<DeviceModel> selectDeviceModelList(DeviceModel deviceModel);

    /**
     * 新增产品型号
     * 
     * @param deviceModel 产品型号
     * @return 结果
     */
    public int insertDeviceModel(DeviceModel deviceModel);

    /**
     * 修改产品型号
     * 
     * @param deviceModel 产品型号
     * @return 结果
     */
    public int updateDeviceModel(DeviceModel deviceModel);

    /**
     * 批量删除产品型号
     * 
     * @param ids 需要删除的产品型号主键集合
     * @return 结果
     */
    public int deleteDeviceModelByIds(Long[] ids);

    /**
     * 删除产品型号信息
     * 
     * @param id 产品型号主键
     * @return 结果
     */
    public int deleteDeviceModelById(Long id);
}
